AlphaXFileTarget class abstract interface

Destination for a native or Dart-managed file download.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Optional display name of the destination.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWrite() Future<AlphaXFileSink>
Opens a destination sink. The transport closes or aborts the sink.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited