AlphaXGet class final

Marks a GET API method.

Constructors

AlphaXGet(String path, {Map<String, String> headers = const <String, String>{}})
Creates GET metadata for path.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Static headers applied to this method.
final
path String
Relative or absolute endpoint path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited