Transport-neutral source of request bytes.
Constructors
-
AlphaXBody.bytes(List<
int> bytes, {String? contentType}) -
Creates an immutable byte request body.
factory
- AlphaXBody.empty()
-
Creates an empty request body.
constfactory
- AlphaXBody.json(Object? value)
-
Creates a JSON request body using
dart:convert.factory - AlphaXBody.text(String text, {Encoding? encoding, String? contentType})
-
Creates a text request body.
factory
Properties
- contentLength → int?
-
Encoded byte length, when known without consuming the body.
no setter
- contentType → String?
-
Content type to apply when the caller has not supplied one.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReplayable → bool
-
Whether the body can be opened again for another attempt.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openStream(
) → Stream< List< int> > - Opens the body for incremental reading.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited