AlphaXCachePolicy class final
Cache behavior for the private HTTP cache middleware.
Constructors
- AlphaXCachePolicy({Duration defaultMaxAge = const Duration(minutes: 5), bool revalidateStale = true, AlphaXCacheScope scope = AlphaXCacheScope.private, String? identityKey})
-
Creates cache behavior.
const
Properties
- defaultMaxAge → Duration
-
Freshness used when a response has no explicit freshness directive.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identityKey → String?
-
Stable, non-secret identity scope for credentialed private responses.
final
- revalidateStale → bool
-
Whether stale entries with validators should be conditionally revalidated.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → AlphaXCacheScope
-
Whether the store is private to an application/client or intentionally shared.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited