AlphaXProtocol enum
Protocol actually negotiated for an AlphaX response.
Values
- unknown → const AlphaXProtocol
-
No protocol was reported by the transport.
- http10 → const AlphaXProtocol
-
HTTP/1.0.
- http11 → const AlphaXProtocol
-
HTTP/1.1.
- http2 → const AlphaXProtocol
-
HTTP/2.
- http3 → const AlphaXProtocol
-
HTTP/3 over QUIC.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlphaXProtocol> - A constant List of the values in this enum, in order of their declaration.